==> fetch.php?media=snfit-2.2.2.tar.gz: snfit-2.2.2/src/integflux.cc <==
#include "sampledfunction.h"
#include "integflux.h"

//static double sq(const double &x) { return x*x;}
#define LAMBDA_STEP 5


double IntegFlux(const Sampled1DFunction &Spectrum, 
		 const Sampled1DFunction &ObserverFilter, 
		 const Sampled1DFunction &RestframeFilter,
		 const double &z, bool do_check_range)
{
  /* number of photons = energy/(h*nu) = energy * wl/(2*pi*hbar*c)
     2*pi* hbar*c = 2* pi * 197 eV nm = 6.28*197 * 1.60e-12 * 10 ergs angst
     = 1.97946e-08
     = 1/5.006909561e07
  */
  if(do_check_range) {
  if(ObserverFilter.Xmin()<Spectrum.Xmin()*(1.+z)) {
#ifdef DEBUG
    cerr << "ObserverFilter xmin < Spectrum xmin*(1.+z), return 0"  << endl;
#endif
    return 0;
  } 
  if(ObserverFilter.Xmax()>Spectrum.Xmax()*(1.+z)) {
#ifdef DEBUG   
    cerr << "ObserverFilter xmax > Spectrum xmax*(1.+z), return 0"  << endl;
#endif
    return 0;
  }
  }

  double nphot = 0;
  double lambda_step =  LAMBDA_STEP;
  for (double lambda = ObserverFilter.Xmin(); lambda <= ObserverFilter.Xmax(); 
       lambda += lambda_step)
    {
      double lambda_sn = lambda/(1+z);
      double nphot_l = Spectrum.Value(lambda_sn) * lambda_sn 
	* RestframeFilter.Value(lambda_sn);
      nphot += ObserverFilter.Value(lambda)*nphot_l;
    }
  return nphot*lambda_step/(1+z) * 5.006909561e7;  
  /* the (1+z) factor is due to the fact that the function says it 
     returns the integral of the spectrum within the blueshifted filter. */
}

double IntegFlux(const Sampled1DFunction &Spectrum,
		 const Sampled1DFunction &Filter, 
		 const double &z, bool do_check_range)
{
  /* number of photons = energy/(h*nu) = energy * wl/(2*pi*hbar*c)
     2*pi* hbar*c = 2* pi * 197 eV nm = 6.28*197 * 1.60e-12 * 10 ergs angst
     = 1.97946e-08
     = 1/5.006909561e07
  */
  if(do_check_range) {
  if(Filter.Xmin()<Spectrum.Xmin()*(1.+z)) {
#ifdef DEBUG
    cerr << "Filter xmin=" << Filter.Xmin() << " < Spectrum xmin*(1+z)=" << Spectrum.Xmin()*(1.+z) << ", return 0"  << endl;
#endif
    return 0;
  } 
  if(Filter.Xmax()>Spectrum.Xmax()*(1.+z)) {
#ifdef DEBUG
    cerr << "Filter xmax=" << Filter.Xmax() << " > Spectrum xmax*(1+z)=" << Spectrum.Xmax()*(1.+z) << ", return 0"  << endl;
#endif
    return 0;
  } 
  }
  
  double nphot = 0;
  double lambda_step = LAMBDA_STEP;
  for (double lambda = Filter.Xmin(); lambda <= Filter.Xmax(); lambda += lambda_step)
    {
      double lambda_sn = lambda/(1+z);
      double nphot_l = Spectrum.Value(lambda_sn) * lambda_sn;
      double fval = Filter.Value(lambda);
      nphot += fval*nphot_l;
      
      //if(nphot_l<0 || fval<0) cerr << lambda_sn << " " << nphot_l << " " << fval << endl;
      
      
    }

  return nphot*lambda_step/(1+z) * 5.006909561e7;  
  /* the (1+z) factor is due to the fact that the function says it 
     returns the integral of the spectrum within the blueshifted filter. */
}


double SumLines(const General1DFunction &Spectrum,
		const Sampled1DFunction &Filter, 
		const double &z)
{
  /* number of photons = energy/(h*nu) = energy * wl/(2*pi*hbar*c)
     2*pi* hbar*c = 2* pi * 197 eV nm = 6.28*197 * 1.60e-12 * 10 ergs angst
     = 1.97946e-08
     = 1/5.006909561e07
  */
 
  
  
  
  const double *w = Spectrum.xvals();
  const double *f = Spectrum.values();
  
  double wmin = Filter.Xmin()/(1.+z);
  double wmax = Filter.Xmax()/(1.+z);
  double redscale   = (1+z);
  double nphot = 0;
  for(int i=0;i<Spectrum.Nval();i++,++w,++f) {
    if(*w<wmin || *w>wmax) continue; // not necessarily ordered
    
    nphot += (*f) * Filter.Value(redscale * (*w)) * (*w);
    
  }
  return nphot*5.006909561e7;  // number of (1+z) compatible with IntegFlux but scale ???
}

double SumLines(const General1DFunction &Spectrum,
		const Sampled1DFunction &ObserverFilter, 
		const Sampled1DFunction &RestframeFilter, 
		const double &z)
{
  /* number of photons = energy/(h*nu) = energy * wl/(2*pi*hbar*c)
     2*pi* hbar*c = 2* pi * 197 eV nm = 6.28*197 * 1.60e-12 * 10 ergs angst
     = 1.97946e-08
     = 1/5.006909561e07
  */
 
  
  
  
  const double *w = Spectrum.xvals();
  const double *f = Spectrum.values();
  
  double wmin = ObserverFilter.Xmin()/(1.+z);
  double wmax = ObserverFilter.Xmax()/(1.+z);
  double redscale   = (1+z);
  double nphot = 0;
  for(int i=0;i<Spectrum.Nval();i++,++w,++f) {
    if(*w<wmin || *w>wmax) continue; // not necessarily ordered
    
    nphot += (*f) * ObserverFilter.Value(redscale * (*w)) * RestframeFilter.Value(*w) * (*w);
    
  }
  return nphot*5.006909561e7;  // number of (1+z) compatible with IntegFlux but scale ???
}

==> fetch.php?media=snfit-2.4.1.tar.gz: snfit-2.4.2/src/integflux.cc <==
#include "sampledfunction.h"
#include "integflux.h"
#include "pathutils.h"
#include "datacards.h"

using namespace std;

static double* IntegFluxWavelengthStep = NULL;

const double& GetWavelengthIntegrationStep() {
  if(IntegFluxWavelengthStep) return *IntegFluxWavelengthStep;
  IntegFluxWavelengthStep = new double();
  *IntegFluxWavelengthStep = 5; // Angstrom
  string dirname = GetDataPath();
  string mainfile = dirname+"/fitmodel.card";
  DataCards cards(mainfile);
  if(cards.HasKey("WAVELENGTH_INTEGRATION_STEP")) {
    *IntegFluxWavelengthStep = cards.DParam("WAVELENGTH_INTEGRATION_STEP");
  }
  cout << "INFO WAVELENGTH_INTEGRATION_STEP = " << *IntegFluxWavelengthStep << endl;
  return *IntegFluxWavelengthStep;
}

double IntegFlux(const Sampled1DFunction &Spectrum, 
		 const Sampled1DFunction &ObserverFilter, 
		 const Sampled1DFunction &RestframeFilter,
		 const double &z, bool do_check_range)
{
  /* number of photons = energy/(h*nu) = energy * wl/(2*pi*hbar*c)
     2*pi* hbar*c = 2* pi * 197 eV nm = 6.28*197 * 1.60e-12 * 10 ergs angst
     = 1.97946e-08
     = 1/5.006909561e07
  */
  if(do_check_range) {
  if(ObserverFilter.Xmin()<Spectrum.Xmin()*(1.+z)) {
#ifdef DEBUG
    cerr << "ObserverFilter xmin < Spectrum xmin*(1.+z), return 0"  << endl;
#endif
    return 0;
  } 
  if(ObserverFilter.Xmax()>Spectrum.Xmax()*(1.+z)) {
#ifdef DEBUG   
    cerr << "ObserverFilter xmax > Spectrum xmax*(1.+z), return 0"  << endl;
#endif
    return 0;
  }
  }

  double nphot = 0;
  double lambda_step = GetWavelengthIntegrationStep();
  for (double lambda = ObserverFilter.Xmin(); lambda <= ObserverFilter.Xmax(); 
       lambda += lambda_step)
    {
      double lambda_sn = lambda/(1+z);
      double nphot_l = Spectrum.Value(lambda_sn) * lambda_sn 
	* RestframeFilter.Value(lambda_sn);
      nphot += ObserverFilter.Value(lambda)*nphot_l;
    }
  return nphot*lambda_step/(1+z) * 5.006909561e7;  
  /* the (1+z) factor is due to the fact that the function says it 
     returns the integral of the spectrum within the blueshifted filter. */
}

double IntegFlux(const Sampled1DFunction &Spectrum,
		 const Sampled1DFunction &Filter, 
		 const double &z, bool do_check_range)
{
  /* number of photons = energy/(h*nu) = energy * wl/(2*pi*hbar*c)
     2*pi* hbar*c = 2* pi * 197 eV nm = 6.28*197 * 1.60e-12 * 10 ergs angst
     = 1.97946e-08
     = 1/5.006909561e07
  */
  if(do_check_range) {
  if(Filter.Xmin()<Spectrum.Xmin()*(1.+z)) {
#ifdef DEBUG
    cerr << "Filter xmin=" << Filter.Xmin() << " < Spectrum xmin*(1+z)=" << Spectrum.Xmin()*(1.+z) << ", return 0"  << endl;
#endif
    return 0;
  } 
  if(Filter.Xmax()>Spectrum.Xmax()*(1.+z)) {
#ifdef DEBUG
    cerr << "Filter xmax=" << Filter.Xmax() << " > Spectrum xmax*(1+z)=" << Spectrum.Xmax()*(1.+z) << ", return 0"  << endl;
#endif
    return 0;
  } 
  }
  
  double nphot = 0;
  double lambda_step = GetWavelengthIntegrationStep();
  for (double lambda = Filter.Xmin(); lambda <= Filter.Xmax(); lambda += lambda_step)
    {
      double lambda_sn = lambda/(1+z);
      double nphot_l = Spectrum.Value(lambda_sn) * lambda_sn;
      double fval = Filter.Value(lambda);
      nphot += fval*nphot_l;
      
      //if(nphot_l<0 || fval<0) cerr << lambda_sn << " " << nphot_l << " " << fval << endl;
      
      
    }

  return nphot*lambda_step/(1+z) * 5.006909561e7;  
  /* the (1+z) factor is due to the fact that the function says it 
     returns the integral of the spectrum within the blueshifted filter. */
}


double SumLines(const General1DFunction &Spectrum,
		const Sampled1DFunction &Filter, 
		const double &z)
{
  /* number of photons = energy/(h*nu) = energy * wl/(2*pi*hbar*c)
     2*pi* hbar*c = 2* pi * 197 eV nm = 6.28*197 * 1.60e-12 * 10 ergs angst
     = 1.97946e-08
     = 1/5.006909561e07
  */
 
  
  
  
  const double *w = Spectrum.xvals();
  const double *f = Spectrum.values();
  
  double wmin = Filter.Xmin()/(1.+z);
  double wmax = Filter.Xmax()/(1.+z);
  double redscale   = (1+z);
  double nphot = 0;
  for(int i=0;i<Spectrum.Nval();i++,++w,++f) {
    if(*w<wmin || *w>wmax) continue; // not necessarily ordered
    
    nphot += (*f) * Filter.Value(redscale * (*w)) * (*w);
    
  }
  return nphot*5.006909561e7;  // number of (1+z) compatible with IntegFlux but scale ???
}

double SumLines(const General1DFunction &Spectrum,
		const Sampled1DFunction &ObserverFilter, 
		const Sampled1DFunction &RestframeFilter, 
		const double &z)
{
  /* number of photons = energy/(h*nu) = energy * wl/(2*pi*hbar*c)
     2*pi* hbar*c = 2* pi * 197 eV nm = 6.28*197 * 1.60e-12 * 10 ergs angst
     = 1.97946e-08
     = 1/5.006909561e07
  */
 
  
  
  
  const double *w = Spectrum.xvals();
  const double *f = Spectrum.values();
  
  double wmin = ObserverFilter.Xmin()/(1.+z);
  double wmax = ObserverFilter.Xmax()/(1.+z);
  double redscale   = (1+z);
  double nphot = 0;
  for(int i=0;i<Spectrum.Nval();i++,++w,++f) {
    if(*w<wmin || *w>wmax) continue; // not necessarily ordered
    
    nphot += (*f) * ObserverFilter.Value(redscale * (*w)) * RestframeFilter.Value(*w) * (*w);
    
  }
  return nphot*5.006909561e7;  // number of (1+z) compatible with IntegFlux but scale ???
}
